# 5320.20 Filler

##### Purpose
The script is designed to allow for automatically filling ATF form 5320.20.

##### Requirements

1. [pdftk-server](https://www.pdflabs.com/tools/pdftk-server/) (Must add to your path enviroment varible).
2. Python version 3.6 or greater.

##### Install
1. ```pip install fill5320```
2. Copy static_data.csv, destinations_data.csv, signature.png, fields.json, atf_form_5320.pdf to directory of choice.

##### Setup
1. Modify owner and firearm information in static_data.csv
2. Modify destinations in destinations_data.csv
3. Edit signature.png

##### Running
1. From the desired working directory ```python -m fill5320```
2. Filled files will be placed in a directory titled filled and signed will be placed in signed

##### Command Line Arugments
1. -i path to static data csv file, default is static_data.csv
2. -d path to destination address file, default is destinations_data.csv
3. -f path to field definition file, default is fields.json This is generated by [pdfforms](https://github.com/altaurog/pdfforms)
4. -s path to signature image file, default is signature.png should be png format and 987x143 pixels.  Other sizes may work, but not tested
5. -p position of signature image on pdf, default 1x70x195x200x12 (page number, x, y, width, height)



[Example Output](https://github.com/prairiesnpr/5320_filler/blob/master/example_output/atf_form_5320_KY.pdf)